@@ -302,3 +302,64 @@ e_aria <- function(e, show = TRUE, ...){
   
   return(e)
 }
+
+#' To & From JSON
+#' 
+#' Get JSON options from an echarts4r object and build one from JSON.
+#' 
+#' @inheritParams e_bar
+#' @param json Whether to return the JSON, otherwise returns a \code{list}.
+#' @param txt JSON character string, url, or file.
+#' @param ... Additional options to pass to \link[jsonlite]{toJSON}.
+#' 
+#' @details \code{txt} should contain the full list of options required to build a chart.
+#' This is subsequently passed to the \code{setOption} ECharts (JavaScript) function.
+#' 
+#' @examples 
+#' p <- cars %>% 
+#'   e_charts(dist) %>% 
+#'   e_scatter(speed, symbol_size = 10) 
+#'  
+#' p # plot
+#' 
+#' # extract the JSON 
+#' json <- p %>% 
+#'   e_inspect(
+#'     json = TRUE,
+#'     pretty = TRUE
+#'   )
+#'   
+#' # print json
+#' json
+#'   
+#' # rebuild plot
+#' echarts_from_json(json) %>% 
+#'   e_theme("dark") # modify
+#' 
+#' @return \code{e_inspect} Returns a \code{list} if \code{json} is \code{FALSE} and a 
+#' JSON string otherwise. \code{echarts_from_json} returns an object of class \code{echarts4r}.
+#' 
+#' @note Must be passed as last option.
+#' 
+#' @rdname echartsNJSON
+#' @export
+e_inspect <- function(e, json = FALSE, ...){
+  opts <- e$x$opts
+  
+  if(isTRUE(json))
+    opts <- jsonlite::toJSON(opts, force = TRUE, auto_unbox = TRUE, null = "null", ...)
+  
+  return(opts)
+}
+
+#' @rdname echartsNJSON
+#' @export
+echarts_from_json <- function(txt){
+  
+  json <- jsonlite::fromJSON(txt, simplifyVector = FALSE)
+  
+  e_charts() -> e
+  e$x$opts <- json
+  e
+  
+}
\ No newline at end of file
